<?xml version="1.0" encoding="UTF-8"?>
<app>

<category>
Language
</category>

<name>
Italian_Firefox
</name>

<description>
   <am>Italian localisation of Firefox</am>
   <ar>Italian localisation of Firefox</ar>
   <be>Italian localisation of Firefox</be>
   <bg>Italian localisation of Firefox</bg>
   <bn>Italian localisation of Firefox</bn>
   <ca>Localització de Firefox en Italià</ca>
   <cs>Italian localisation of Firefox</cs>
   <da>Italiensk oversættelse af Firefox</da>
   <de>Italienische Lokalisierung von Firefox</de>
   <el>Ιταλικά για το Firefox</el>
   <en>Italian localisation of Firefox</en>
   <es_ES>Localización Italiana de Firefox</es_ES>
   <es>Localización Italiano de Firefox</es>
   <et>Italian localisation of Firefox</et>
   <eu>Italian localisation of Firefox</eu>
   <fa>Italian localisation of Firefox</fa>
   <fil_PH>Italian localisation of Firefox</fil_PH>
   <fi>Italialainen Firefox-kotoistus</fi>
   <fr_BE>Localisation en italien pour Firefox</fr_BE>
   <fr>Localisation en italien pour Firefox</fr>
   <gl_ES>Localización do Firefox ao italiano</gl_ES>
   <gu>Italian localisation of Firefox</gu>
   <he_IL>תרגומי Firefox לאיטלקית</he_IL>
   <hi>फायरफॉक्स का इतालवी संस्करण</hi>
   <hr>Italian localisation of Firefox</hr>
   <hu>Italian localisation of Firefox</hu>
   <id>Italian localisation of Firefox</id>
   <is>Italian localisation of Firefox</is>
   <it>Localizzazione italiana di Firefox</it>
   <ja>Firefox のイタリア語版</ja>
   <kk>Italian localisation of Firefox</kk>
   <ko>Italian localisation of Firefox</ko>
   <ku>Italian localisation of Firefox</ku>
   <lt>Italian localisation of Firefox</lt>
   <mk>Italian localisation of Firefox</mk>
   <mr>Italian localisation of Firefox</mr>
   <nb_NO>Italian localisation of Firefox</nb_NO>
   <nb>Italiensk lokaltilpassing av Firefox</nb>
   <nl_BE>Italian localisation of Firefox</nl_BE>
   <nl>Italiaanse lokalisatie van Firefox</nl>
   <or>Italian localisation of Firefox</or>
   <pl>Włoska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Italiano Localização para o Firefox</pt_BR>
   <pt>Italiano Localização para Firefox</pt>
   <ro>Italian localisation of Firefox</ro>
   <ru>Итальянская локализация Firefox</ru>
   <sk>Italian localisation of Firefox</sk>
   <sl>Italijanske krajevne nastavitve za Firefox</sl>
   <so>Italian localisation of Firefox</so>
   <sq>Përkthimi i Firefox-it në italisht</sq>
   <sr>Italian localisation of Firefox</sr>
   <sv>Italiensk lokalisering av Firefox </sv>
   <th>Italian localisation ของFirefox</th>
   <tr>Firefox'un İtalyanca yerelleştirmesi</tr>
   <uk>Italian локалізація Firefox</uk>
   <vi>Italian localisation of Firefox</vi>
   <zh_CN>Italian localisation of Firefox</zh_CN>
   <zh_HK>Italian localisation of Firefox</zh_HK>
   <zh_TW>Italian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-it
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-it
</uninstall_package_names>
</app>
